﻿using System.Collections.ObjectModel;

namespace Model.Stub
{
    public class StubAlbum
    {
        public StubArtist StubArtist
        {
            get
            {
                return stubArtist;
            }
        }

        private readonly StubArtist stubArtist;

        public ObservableCollection<Album> Albums
        {
            get => albums;
        }

        private readonly ObservableCollection<Album> albums;

        /// <summary>
        /// Constructeur de la classe StubAlbum
        /// </summary>
        public StubAlbum()
        {
            stubArtist = new StubArtist();
            albums = new ObservableCollection<Album>()
            {
                new Album("Adios Bahamas", "album1.jpg", StubArtist.GetArtistByName("Népal") ?? new Artist("Népal"), "Album post-mortem qui signé également le dernier de l'artiste", "Sortie : 2020"),
                new Album("445e Nuit", "album2.jpg", StubArtist.GetArtistByName("Népal") ?? new Artist("Népal"), "", "Sortie : 2017\n8 titres - 24 min"),
                new Album("Fenêtre Sur Rue", "album3.jpg", StubArtist.GetArtistByName("Hugo TSR") ?? new Artist("Hugo TSR"), "", "Sortie : 2012\n14 titres - 46 min"),
                new Album("Temps Mort", "album4.jpg", StubArtist.GetArtistByName("Booba") ?? new Artist("Booba"), "Premier album de Booba", "Sortie : 2002\n14 titres - 57 min"),
                new Album("Opéra Puccino", "album5.jpg", StubArtist.GetArtistByName("Oxmo Puccino") ?? new Artist("Oxmo Puccino"), "", "Sortie : 1998\n18 titres - 1h08min"),
                new Album("L'école du micro d'argent", "album6.jpg", StubArtist.GetArtistByName("IAM") ?? new Artist("IAM"), "", "Sortie : 1997\n16 titres - 1h13min"),
                new Album("Deux Frères", "album7.png", StubArtist.GetArtistByName("PNL") ?? new Artist("PNL"), "", "Sortie : 2019\n22 titres"),
                new Album("Dans la légende", "album8.jpg", StubArtist.GetArtistByName("PNL") ?? new Artist("PNL"), "", "Sortie : 2016\n16 titres - 1h06"),
                new Album("Night Visions", "album9.jpg", StubArtist.GetArtistByName("Imagine Dragons") ?? new Artist("Imagine Dragons"), "", ""),
                new Album("Smoke & Mirrors", "album10.jpg", StubArtist.GetArtistByName("Imagine Dragons") ?? new Artist("Imagine Dragons"), "", ""),
                new Album("Evolve", "album11.jpg", StubArtist.GetArtistByName("Imagine Dragons") ?? new Artist("Imagine Dragons"), "", ""),
                new Album("Origins", "album12.jpg", StubArtist.GetArtistByName("Imagine Dragons") ?? new Artist("Imagine Dragons"), "", ""),
                new Album("Mercury Act 1", "album13.jpg", StubArtist.GetArtistByName("Imagine Dragons") ?? new Artist("Imagine Dragons"), "", ""),
                new Album("Mercury Act 2", "album14.jpg", StubArtist.GetArtistByName("Imagine Dragons") ?? new Artist("Imagine Dragons"), "", "")
            };
        }

        /// <summary>
        /// Permet d'obtenir la liste des albums
        /// </summary>
        /// <returns>Retourne la liste des albums</returns>
        public ObservableCollection<Album> GetAlbums()
        {
            return albums;
        }

        /// <summary>
        /// Permet d'obtenir un album selon son nom
        /// </summary>
        /// <param name="name">Nom de l'album recherché</param>
        /// <returns>Retourne l'album correspondant au nom donné en paramètre</returns>
        public Album GetAlbumByName(string name)
        {
            foreach (Album album in albums)
            {
                if (name == album.Name)
                {
                    return album;
                }
            }
            return null;
        }

        /// <summary>
        /// Permet d'ajouter un album à la liste des albums
        /// </summary>
        /// <param name="album">Album à ajouter</param>
        public void AddAlbum(Album album)
        {
            albums.Add(album);
        }

        /// <summary>
        /// Permet de retirer un album de la liste des albums
        /// </summary>
        /// <param name="album">Album à retirer</param>
        public void RemoveAlbum(Album album)
        {
            albums.Remove(album);
        }
    }
}